pub struct VisualizeAabbItem<T: Aabb>(pub T);Expand description
Wrapper that visualizes the AABB of the inner item as a wireframe rectangle.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Aabb> Aabb for VisualizeAabbItem<T>
impl<T: Aabb> Aabb for VisualizeAabbItem<T>
Sourceimpl<T: Clone + Aabb> Clone for VisualizeAabbItem<T>
impl<T: Clone + Aabb> Clone for VisualizeAabbItem<T>
Sourcefn clone(&self) -> VisualizeAabbItem<T>
fn clone(&self) -> VisualizeAabbItem<T>
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Aabb> Deref for VisualizeAabbItem<T>
impl<T: Aabb> Deref for VisualizeAabbItem<T>
Sourceimpl<T: Aabb> DerefMut for VisualizeAabbItem<T>
impl<T: Aabb> DerefMut for VisualizeAabbItem<T>
Sourceimpl<T: Aabb + RotateTransform> RotateTransform for VisualizeAabbItem<T>
impl<T: Aabb + RotateTransform> RotateTransform for VisualizeAabbItem<T>
Sourcefn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Self
fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Self
Rotate the item by a given angle about a given axis.
Sourcefn rotate_on_x(&mut self, angle: f64) -> &mut Self
fn rotate_on_x(&mut self, angle: f64) -> &mut Self
Rotate the item by a given angle about the X axis.
Sourcefn rotate_on_y(&mut self, angle: f64) -> &mut Self
fn rotate_on_y(&mut self, angle: f64) -> &mut Self
Rotate the item by a given angle about the Y axis.
Sourcefn rotate_on_z(&mut self, angle: f64) -> &mut Self
fn rotate_on_z(&mut self, angle: f64) -> &mut Self
Rotate the item by a given angle about the Z axis.
Sourceimpl<T: Aabb + ScaleTransform> ScaleTransform for VisualizeAabbItem<T>
impl<T: Aabb + ScaleTransform> ScaleTransform for VisualizeAabbItem<T>
Sourceimpl<T: Aabb + ShiftTransform> ShiftTransform for VisualizeAabbItem<T>
impl<T: Aabb + ShiftTransform> ShiftTransform for VisualizeAabbItem<T>